# Student-repos-handler

Simple tool to handle multiple repos at once, oriented to the grading of assignments in UCSE DAR.


# Installation

```
pip3 install student-repos-handler --user
```

# Usage

Run `repos` to get the help on the available commands.
